#!/bin/sh

# This script is used to start the probe aggregator with an embedded probe.

if [ -z "$R3_PROBE_HOME" ] ; then
  # $0 is path to script
  PRG="$0"

  # loop resolving symlinks
  while [ -h "$PRG" ] ; do
    ls=`ls -ld "$PRG"`
    link=`expr "$ls" : '.*-> \(.*\)$'`
    if expr "$link" : '/.*' > /dev/null; then
      PRG="$link"
    else
      PRG=`dirname "$PRG"`"/$link"
    fi
  done

  # the parent of the 'bin' directory:
  PROBEAGGREGATOR_HOME=`dirname "$PRG"`/..

  # get rid of the /.. part:
  PROBEAGGREGATOR_HOME=`cd "$PROBEAGGREGATOR_HOME" >/dev/null && pwd`
  export USE_THRIFT="true"

fi

if [ "$OSTYPE" = "cygwin" ] ; then
  PATHSEP=\;
  PROBEAGGREGATOR_HOME=`cygpath -d -a $PROBEAGGREGATOR_HOME`
else
  PATHSEP=:
fi

echo PROBEAGGREGATOR_HOME="$PROBEAGGREGATOR_HOME"
          
if [ -x "$PROBEAGGREGATOR_HOME/jre/bin/java" ]
then
  JAVA1_7_HOME="$PROBEAGGREGATOR_HOME/jre"
else
  if [ -z "$JAVA1_7_HOME" ]
  then
    echo Please set JAVA1_7_HOME to a valid JRE 1.7.0 installation.
    exit 1
  else
    echo WARNING - Make sure that JAVA1_7_HOME is set to a valid JRE 1.7.0 installation.
  fi
fi

kernel=`uname -s`
if [ ${kernel} = "SunOS" ]; then
    LD_LIBRARY_PATH=$PROBEAGGREGATOR_HOME/nanny/solaris/bin:$LD_LIBRARY_PATH
    export LD_LIBRARY_PATH
else
    LD_LIBRARY_PATH=$PROBEAGGREGATOR_HOME/lib/linux:$LD_LIBRARY_PATH
    export LD_LIBRARY_PATH
fi

#
# Use Automatic Explicit instrumentation
#
#$JAVA1_7_HOME/bin/java -server -jar "$PROBEAGGREGATOR_HOME/probe/lib/jreinstrumenter.jar" -f ProbeAggregator

#PROBEAGGREGATOR_BCP1=-Xbootclasspath/p:$PROBEAGGREGATOR_HOME/probe/classes/ProbeAggregator/instr.jre
#PROBEAGGREGATOR_BCP2=-javaagent:$PROBEAGGREGATOR_HOME/probe/lib/probeagent.jar

#
# Now we can actually start the -probe. As long as it exits with an exit code
#   less than or equal to zero, we'll restart it...
#
PROBEAGGREGATORExitCode=0
echo "PROBEAGGREGATOR_HOME=$PROBEAGGREGATOR_HOME"
while [ $PROBEAGGREGATORExitCode -le 0 ]; do
  DEBUG="-Xdebug -Xrunjdwp:transport=dt_socket,server=y,suspend=n,address=5005"
  $JAVA1_7_HOME/bin/java -server -Xdebug -Xrunjdwp:transport=dt_socket,server=y,suspend=n,address=5005 -Xmx512m -Dsun.net.client.defaultReadTimeout=70000 -Dsun.net.client.defaultConnectTimeout=30000  $JAVAOPTS -jar "$PROBEAGGREGATOR_HOME/lib/probeaggregator.jar" true 
  PROBEAGGREGATORExitCode=$?

  echo " PROBEAGGREGATOR exited with code: "$PROBEAGGREGATORExitCode
  
done
